@@ -1,6 +1,7 @@
-from ..elements import Element,Link,Header,Br
+from ..elements import Element, Link, Header, Br
 from typing import List, Any
 
+
 class Section:
     title: str = ""
     inner: List[Element] = []
@@ -25,11 +26,12 @@ class Readme:
     sections: List[Section] = []
     have_header: bool = True
 
-    def __init__(self, title: str = "", description: str = "", sections: List[Section] = [], badges: List[Any] = []) -> None:
+    def __init__(self, title: str = "", description: str = "", sections: List[Section] = [], badges: List[Any] = [], have_header: bool = True) -> None:
         self.title = title
         self.description = description
         self.badges = badges
         self.sections = sections
+        self.have_header = have_header
 
     def to_markdown(self):
         from ..generator import md
